@@ -1,6 +1,5 @@
-from http import HTTPStatus
 from ssl import SSLContext
-from typing import AsyncIterator, Dict, List, Tuple
+from typing import AsyncIterator, Dict, List, Tuple, cast
 
 import h2.connection
 import h2.events
@@ -8,7 +7,7 @@ from h2.config import H2Configuration
 from h2.exceptions import NoAvailableStreamIDError
 from h2.settings import SettingCodes, Settings
 
-from .._backends.auto import AsyncLock, AsyncSemaphore, AsyncSocketStream, AutoBackend
+from .._backends.auto import AsyncBackend, AsyncLock, AsyncSemaphore, AsyncSocketStream
 from .._bytestreams import AsyncIteratorByteStream, PlainByteStream
 from .._exceptions import PoolTimeout, RemoteProtocolError
 from .._types import URL, Headers, TimeoutDict
@@ -19,13 +18,6 @@ from .http import AsyncBaseHTTPConnection
 logger = get_logger(__name__)
 
 
-def get_reason_phrase(status_code: int) -> bytes:
-    try:
-        return HTTPStatus(status_code).phrase.encode("ascii")
-    except ValueError:
-        return b""
-
-
 class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
     READ_NUM_BYTES = 64 * 1024
     CONFIG = H2Configuration(validate_inbound_headers=False)
@@ -33,7 +25,7 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
     def __init__(
         self,
         socket: AsyncSocketStream,
-        backend: AutoBackend,
+        backend: AsyncBackend,
         ssl_context: SSLContext = None,
     ):
         self.socket = socket
@@ -93,15 +85,16 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
         if self.state == ConnectionState.IDLE:
             self.state = ConnectionState.READY
 
-    async def request(
+    async def arequest(
         self,
         method: bytes,
         url: URL,
         headers: Headers = None,
         stream: AsyncByteStream = None,
-        timeout: TimeoutDict = None,
-    ) -> Tuple[bytes, int, bytes, List[Tuple[bytes, bytes]], AsyncByteStream]:
-        timeout = {} if timeout is None else timeout
+        ext: dict = None,
+    ) -> Tuple[int, Headers, AsyncByteStream, dict]:
+        ext = {} if ext is None else ext
+        timeout = cast(TimeoutDict, ext.get("timeout", {}))
 
         async with self.init_lock:
             if not self.sent_connection_init:
@@ -123,9 +116,9 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
             h2_stream = AsyncHTTP2Stream(stream_id=stream_id, connection=self)
             self.streams[stream_id] = h2_stream
             self.events[stream_id] = []
-            return await h2_stream.request(method, url, headers, stream, timeout)
-        except Exception:
-            self.max_streams_semaphore.release()
+            return await h2_stream.arequest(method, url, headers, stream, ext)
+        except Exception:  # noqa: PIE786
+            await self.max_streams_semaphore.release()
             raise
 
     async def send_connection_init(self, timeout: TimeoutDict) -> None:
@@ -228,7 +221,7 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
         await self.socket.write(data_to_send, timeout)
 
     async def send_headers(
-        self, stream_id: int, headers: Headers, end_stream: bool, timeout: TimeoutDict,
+        self, stream_id: int, headers: Headers, end_stream: bool, timeout: TimeoutDict
     ) -> None:
         logger.trace("send_headers stream_id=%r headers=%r", stream_id, headers)
         self.h2_state.send_headers(stream_id, headers, end_stream=end_stream)
@@ -269,7 +262,7 @@ class AsyncHTTP2Connection(AsyncBaseHTTPConnection):
                 elif self.state == ConnectionState.FULL:
                     await self.aclose()
         finally:
-            self.max_streams_semaphore.release()
+            await self.max_streams_semaphore.release()
 
 
 class AsyncHTTP2Stream:
@@ -277,17 +270,18 @@ class AsyncHTTP2Stream:
         self.stream_id = stream_id
         self.connection = connection
 
-    async def request(
+    async def arequest(
         self,
         method: bytes,
         url: URL,
         headers: Headers = None,
         stream: AsyncByteStream = None,
-        timeout: TimeoutDict = None,
-    ) -> Tuple[bytes, int, bytes, List[Tuple[bytes, bytes]], AsyncByteStream]:
+        ext: dict = None,
+    ) -> Tuple[int, Headers, AsyncByteStream, dict]:
         headers = [] if headers is None else [(k.lower(), v) for (k, v) in headers]
         stream = PlainByteStream(b"") if stream is None else stream
-        timeout = {} if timeout is None else timeout
+        ext = {} if ext is None else ext
+        timeout = cast(TimeoutDict, ext.get("timeout", {}))
 
         # Send the request.
         seen_headers = set(key for key, value in headers)
@@ -301,12 +295,14 @@ class AsyncHTTP2Stream:
 
         # Receive the response.
         status_code, headers = await self.receive_response(timeout)
-        reason_phrase = get_reason_phrase(status_code)
         response_stream = AsyncIteratorByteStream(
             aiterator=self.body_iter(timeout), aclose_func=self._response_closed
         )
 
-        return (b"HTTP/2", status_code, reason_phrase, headers, response_stream)
+        ext = {
+            "http_version": "HTTP/2",
+        }
+        return (status_code, headers, response_stream, ext)
 
     async def send_headers(
         self,
