@@ -6,7 +6,7 @@ from typing import Dict, Iterator, Type
 def map_exceptions(map: Dict[Type[Exception], Type[Exception]]) -> Iterator[None]:
     try:
         yield
-    except Exception as exc:
+    except Exception as exc:  # noqa: PIE786
         for from_exc, to_exc in map.items():
             if isinstance(exc, from_exc):
                 raise to_exc(exc) from None
